==> htcheck_1.1.orig.tar.gz: htcheck-1.1.orig/htcommon/SchedulerEntry.cc <==
///////
   //    SchedulerEntry .cc
   //    Scheduler Entry Class definitions
   //
   //    Class for interfacing the Schedule table of the DB
   //
   //    Copyright (c) 1999-2002 Comune di Prato - Prato - Italy
   //    Author: Gabriele Bartolini - Prato - Italy <angusgb@users.sourceforge.net>
   //
   //    For copyright details, see the file COPYING in your distribution
   //    or the GNU General Public License version 2 or later 
   //    <http://www.gnu.org/copyleft/gpl.html>
   //
   //    $Id: SchedulerEntry.cc,v 1.14 2002/02/18 10:44:59 angusgb Exp $
   //
   //    G.Bartolini
   //    started: 14.09.1999
///////

#include "_Server.h"
#include "SchedulerEntry.h"

   // Static variables initialization
      int SchedulerEntry::debug = 0;

///////
   //    Construction
///////

SchedulerEntry::SchedulerEntry(const String &u)
{
   SetNewUrl(u);
}

///////
   //    Destruction
///////

SchedulerEntry::~SchedulerEntry ()
{
}

///////
   //    Reset the schedule content
///////

void SchedulerEntry::Reset()
{
   ScheduleUrl.trunc();
   IDSchedule=0;
   IDServer=0;
   IDReferer=0;
   HopCount=0;
   server=0;
   Status=Url_Empty;
   is_malformed=false;
}


///////
   //    Set the new url to the schedule
///////

void SchedulerEntry::SetNewUrl(const String &u)
{
   Reset();
   SetScheduleUrl(u);
}


///////
   //    Converts the Schedule_Status value into the corresponding
   //    String value
///////

void SchedulerEntry::RetrieveStatus(String &Status) const
{

   switch(GetStatus())
   {
      case (Url_Empty):
         Status="";
         break;
      case (Url_ToBeRetrieved):
         Status="ToBeRetrieved";
         break;
      case (Url_Retrieved):
         Status="Retrieved";
         break;
      case (Url_CheckIfExists):
         Status="CheckIfExists";
         break;
      case (Url_Checked):
         Status="Checked";
         break;
      case (Url_BadQueryString):
         Status="BadQueryString";
         break;
      case (Url_BadExtension):
         Status="BadExtension";
         break;
      case (Url_MaxHopCount):
         Status="MaxHopCount";
         break;
      case (Url_FileProtocol):
         Status="FileProtocol";
         break;
      case (Url_EMail):
         Status="EMail";
         break;
      case (Url_Javascript):
         Status="Javascript";
         break;
      case (Url_NotValidService):
         Status="NotValidService";
         break;
      case (Url_Malformed):
         Status="Malformed";
         break;
   }

}


///////
   //    Set the server ID, given a server
   //    if the server is null, ID is set to 0
///////

void SchedulerEntry::SetServer (_Server *s)
{
   server = s;
   if (s) IDServer = s->GetID();
   else IDServer = 0;
}


///////
   //    Converts the Status string value
   //    into the corresponding Schedule_Status value 
   //    Returns 0 if an error occurs, 1 if OK.
///////

int SchedulerEntry::SetStatus(const String &Status)
{

   if (!strcmp(Status, ""))
      SetStatus (Url_Empty);
   if (!strcmp(Status, "ToBeRetrieved"))
      SetStatus (Url_ToBeRetrieved);
   else if (!strcmp(Status, "Retrieved"))
      SetStatus (Url_Retrieved);
   else if (!strcmp(Status, "CheckIfExists"))
      SetStatus (Url_CheckIfExists);
   else if (!strcmp(Status, "Checked"))
      SetStatus (Url_Checked);
   else if (!strcmp(Status, "BadQueryString"))
      SetStatus (Url_BadQueryString);
   else if (!strcmp(Status, "BadExtension"))
      SetStatus (Url_BadExtension);
   else if (!strcmp(Status, "MaxHopCount"))
      SetStatus (Url_MaxHopCount);
   else if (!strcmp(Status, "FileProtocol"))
      SetStatus (Url_FileProtocol);
   else if (!strcmp(Status, "EMail"))
      SetStatus (Url_EMail);
   else if (!strcmp(Status, "Javascript"))
      SetStatus (Url_Javascript);
   else if (!strcmp(Status, "NotValidService"))
      SetStatus (Url_NotValidService);
   else if (!strcmp(Status, "Malformed"))
      SetStatus (Url_Malformed);
   else return 0;
   
   return 1;
}


///////
   //    Output SchedulerEntry object
///////
ostream& operator<<( ostream &output, const SchedulerEntry &s)
{
   output << s.ScheduleUrl;
   
   if (s.debug < 3) return output;
   
   // Only if debug level is greater than 2
   
   output << " (ID: " << s.IDSchedule << " / "
      << "IDServer: " << s.IDServer << " / ";

   String Status="";

   s.RetrieveStatus(Status);

   if (!strcmp ((char *)Status, ""))
      Status = "Not yet assigned";
      
   output << (int) s.Status << " - " << Status << " )";
   
   if (s.server)
      output << " Server: " << s.server->host() << ":" << s.server->port();
   
   return output;
}

==> htcheck_1.2.4~rc1.orig.tar.gz: htcheck-1.2.4-rc1/htcommon/SchedulerEntry.cc <==
///////
   //    SchedulerEntry .cc
   //    Scheduler Entry Class definitions
   //
   //    Class for interfacing the Schedule table of the DB
   //
   //    Copyright (c) 1999-2004 Comune di Prato - Prato - Italy
   //    Author: Gabriele Bartolini - Prato - Italy <angusgb@users.sourceforge.net>
   //
   //    For copyright details, see the file COPYING in your distribution
   //    or the GNU General Public License version 2 or later 
   //    <http://www.gnu.org/copyleft/gpl.html>
   //
   //    $Id: SchedulerEntry.cc,v 1.22 2003/12/30 09:38:47 angusgb Exp $
   //
   //    G.Bartolini
   //    started: 14.09.1999
///////

#ifdef HAVE_CONFIG_H
#include "htconfig.h"
#endif /* HAVE_CONFIG_H */

#include "_Server.h"
#include "SchedulerEntry.h"

   // Static variables initialization
      int SchedulerEntry::debug = 0;

///////
   //    Construction
///////

// Default constructor
SchedulerEntry::SchedulerEntry()
: 
IDSchedule(0),
IDServer(0),
server(0),
ScheduleUrl(0),
Status(Url_Empty),
Domain(Url_Unknown),
IDReferer(0),
HopCount(0),
is_malformed(0)
{
}

// From a string containing an URL
SchedulerEntry::SchedulerEntry(const String &u)
: 
IDSchedule(0),
IDServer(0),
server(0),
ScheduleUrl(0),
Status(Url_Empty),
Domain(Url_Unknown),
IDReferer(0),
HopCount(0),
is_malformed(0)
{
   SetNewUrl(u);
}

///////
   //    Destruction
///////

SchedulerEntry::~SchedulerEntry ()
{
}

///////
   //    Reset the schedule content
///////

void SchedulerEntry::Reset()
{
   ScheduleUrl.trunc();
   IDSchedule=0;
   IDServer=0;
   IDReferer=0;
   HopCount=0;
   server=0;
   Status=Url_Empty;
   Domain=Url_Unknown;
   is_malformed=false;
}


///////
   //    Set the new url to the schedule
///////

void SchedulerEntry::SetNewUrl(const String &u)
{
   Reset();
   SetScheduleUrl(u);
}


///////
   //    Converts the Schedule_Status value into the corresponding
   //    String value
///////

void SchedulerEntry::RetrieveStatus(String &Status) const
{

   switch(GetStatus())
   {
      case (Url_Empty):
         Status.trunc();
         break;
      case (Url_ToBeRetrieved):
         Status="ToBeRetrieved";
         break;
      case (Url_Retrieved):
         Status="Retrieved";
         break;
      case (Url_CheckIfExists):
         Status="CheckIfExists";
         break;
      case (Url_Checked):
         Status="Checked";
         break;
      case (Url_BadQueryString):
         Status="BadQueryString";
         break;
      case (Url_BadExtension):
         Status="BadExtension";
         break;
      case (Url_MaxHopCount):
         Status="MaxHopCount";
         break;
      case (Url_FileProtocol):
         Status="FileProtocol";
         break;
      case (Url_EMail):
         Status="EMail";
         break;
      case (Url_Javascript):
         Status="Javascript";
         break;
      case (Url_NotValidService):
         Status="NotValidService";
         break;
      case (Url_Malformed):
         Status="Malformed";
         break;
   }

}


///////
   //    Converts the Schedule_Domain value into the corresponding
   //    String value
///////

void SchedulerEntry::RetrieveDomain(String &Domain) const
{

   switch(GetDomain())
   {
      case (Url_Unknown):
         Domain.trunc();
         break;
      case (Url_Internal):
         Domain="Internal";
         break;
      case (Url_External):
         Domain="External";
         break;
   }

}


///////
   //    Set the server ID, given a server
   //    if the server is null, ID is set to 0
///////

void SchedulerEntry::SetServer (_Server *s)
{
   server = s;
   if (s) IDServer = s->GetID();
   else IDServer = 0;
}


///////
   //    Converts the Status string value
   //    into the corresponding Schedule_Status value 
   //    Returns 0 if an error occurs, 1 if OK.
///////

int SchedulerEntry::SetStatus(const String &Status)
{

   if (!Status.length())
      SetStatus (Url_Empty);
   if (Status == static_cast<String> ("ToBeRetrieved"))
      SetStatus (Url_ToBeRetrieved);
   else if (Status == static_cast<String> ("Retrieved"))
      SetStatus (Url_Retrieved);
   else if (Status == static_cast<String> ("CheckIfExists"))
      SetStatus (Url_CheckIfExists);
   else if (Status == static_cast<String> ("Checked"))
      SetStatus (Url_Checked);
   else if (Status == static_cast<String> ("BadQueryString"))
      SetStatus (Url_BadQueryString);
   else if (Status == static_cast<String> ("BadExtension"))
      SetStatus (Url_BadExtension);
   else if (Status == static_cast<String> ("MaxHopCount"))
      SetStatus (Url_MaxHopCount);
   else if (Status == static_cast<String> ("FileProtocol"))
      SetStatus (Url_FileProtocol);
   else if (Status == static_cast<String> ("EMail"))
      SetStatus (Url_EMail);
   else if (Status == static_cast<String> ("Javascript"))
      SetStatus (Url_Javascript);
   else if (Status == static_cast<String> ("NotValidService"))
      SetStatus (Url_NotValidService);
   else if (Status == static_cast<String> ("Malformed"))
      SetStatus (Url_Malformed);
   else return 0;
   
   return 1;
}


///////
   //    Converts the Domain string value
   //    into the corresponding Schedule_Domain value 
   //    Returns 0 if an error occurs, 1 if OK.
///////

int SchedulerEntry::SetDomain(const String &Domain)
{

   if (!Domain.length())
      SetDomain (Url_Unknown);
   if (Domain == static_cast<String> ("Internal"))
      SetDomain (Url_ToBeRetrieved);
   else if (Domain == static_cast<String> ("Retrieved"))
      SetDomain (Url_Retrieved);
   else return 0;
   
   return 1;
}


///////
   //    Output SchedulerEntry object
///////
ostream& operator<<( ostream &output, const SchedulerEntry &s)
{
   output << s.ScheduleUrl;
   
   if (s.debug < 3) return output;
   
   // Only if debug level is greater than 2
   
   output << " (ID: " << s.IDSchedule << " / "
      << "IDServer: " << s.IDServer << " / ";

   String Status="";

   s.RetrieveStatus(Status);

   if (!Status.length())
      Status = "Not yet assigned";
      
   String Domain="";

   s.RetrieveDomain(Domain);

   if (!Domain.length())
      Domain = "Not yet assigned";
      
   output << (int) s.Status << " - " << Status << " / "
      << (int) s.Domain << " - " << Domain << " )";
   
   if (s.server)
      output << " Server: " << s.server->host() << ":" << s.server->port();
   
   return output;
}
